Module stellar_client::client [−][src]
This modulbe encompasses the major clients for the stellar sdk. It's
basically divided into the synchronous client and the asynchronous. The
synchronous client utilitizes reqwest under the hood and will block
the current thread until a response has been received and processed.
In contrast, the async client will return a future for execution on the event loop and will yield the returned resource as a result of a future.
Modules
| async |
This module contains the client for asynchronous communcation. |
| sync |
This module contains the client for synchronous communcation. A synchronous
client is one that will block the calling thread until a response has been
returned. It requires that the caller passes it a struct that implements
the |