Struct stellar_client::endpoint::account::Transactions [−][src]
pub struct Transactions { /* fields omitted */ }Represents the transaction for account endpoint on the stellar horizon server. The endpoint will return all the transactions that have effected a specific account
https://www.stellar.org/developers/horizon/reference/endpoints/transactions-for-account.html
Example
use stellar_client::sync::Client; use stellar_client::endpoint::{account, transaction, Limit}; let client = Client::horizon_test().unwrap(); // Grab transaction and associated account to ensure an account populated with transactions let transaction_ep = transaction::All::default().with_limit(1); let all_txns = client.request(transaction_ep).unwrap(); let txn = &all_txns.records()[0]; let account_id = txn.source_account(); // Now we issue a request for that account's transactions let endpoint = account::Transactions::new(account_id); let acct_txns = client.request(endpoint).unwrap(); assert!(acct_txns.records().len() > 0);
Methods
impl Transactions[src]
impl Transactionspub fn new(account_id: &str) -> Self[src]
pub fn new(account_id: &str) -> SelfCreates a new account::Transactions endpoint struct. Hand this to the client in order to request transactions for a specific account.
use stellar_client::endpoint::account; let txns = account::Transactions::new("abc123");