Module stellar_client::endpoint::ledger[][src]

Contains the endpoint for all ledgers.

Structs

All

Represents the all ledgers end point for the stellar horizon server. The endpoint will return all ledgers filtered by a myriad of different query params.

Details

Represents the ledger details endpoint for the stellar horizon server. The endpoint will return a single ledger's details.

Effects

Represents the effects for ledger endpoint on the stellar horizon server. The endpoint will return all the effects for a single ledger in the chain.

Operations

Represents the operations for ledger endpoint on the stellar horizon server. The endpoint will return all the operations for a single ledger in the chain.

Payments

Represents the payments for ledger endpoint on the stellar horizon server. The endpoint will return all the payment for a single ledger in the chain.

Transactions

Represents the transactions for ledger endpoint on the stellar horizon server. The endpoint will return all the transactions for a single ledger in the chain.