Module stellar_client::endpoint::payment[][src]

Contains the endpoint for all payment operations.

Re-exports

pub use super::account::Payments as ForAccount;
pub use super::ledger::Payments as ForLedger;
pub use super::transaction::Payments as ForTransaction;

Structs

All

This endpoint represents all payment operations that are part of validated transactions. The endpoint will return all payments and accepts query params for a cursor, order, and limit.

FindPath

This endpoint represents a search for a series of assets through which to route a payment, from source asset (debited from payer) to destination asset (credited to payee). The endpoint will return any payment paths using assets available to a source account to the desired destination asset.