Module stellar_client::resources::operation [−][src]
An operation is an individual command that mutates the ledger.
Modules
| prelude |
Use this to quickly load all the operation structs into the current scope. |
Structs
| AccountMerge |
Removes the account and transfers all remaining XLM to the destination account. |
| AllowTrust |
Updates the “authorized” flag of an existing trust line this is called by the issuer of the asset. |
| ChangeTrust |
Use “Change Trust” operation to create/update/delete a trust line from the source account to another. The issuer being trusted and the asset code are in the given Asset object. |
| CreateAccount |
A create account operation represents a new account creation. |
| CreatePassiveOffer |
“Create Passive Offer” operation creates an offer that won’t consume a counter offer that exactly matches this offer. This is useful for offers just used as 1:1 exchanges for path payments. Use Manage Offer to manage this offer after using this operation to create it. |
| ManageData |
Set, modify or delete a Data Entry (name/value pair) for an account. |
| ManageOffer |
A “Manage Offer” operation can create, update or delete an offer to trade assets in the Stellar network. It specifies an issuer, a price and amount of a given asset to buy or sell. |
| Operation |
Operations are objects that represent a desired change to the ledger: payments, offers to exchange currency, changes made to account options, etc. Operations are submitted to the Stellar network grouped in a Transaction. |
| PathPayment |
A path payment operation represents a payment from one account to another through a path. This type of payment starts as one type of asset and ends as another type of asset. There can be other assets that are traded into and out of along the path. |
| Payment |
A payment operation represents a payment from one account to another. This payment can be either a simple native asset payment or a fiat asset payment. |
| SetOptions |
Use “Set Options” operation to set following options to your account: |
Enums
| OperationKind |
Each operation type is representing by a kind and captures data specific to that type within it's newtype. |