Struct stellar_client::endpoint::account::Trades [−][src]
pub struct Trades { /* fields omitted */ }Represents the trades for account endpoint on the stellar horizon server. The endpoint will return all the trades for a specific account
https://www.stellar.org/developers/horizon/reference/endpoints/trades-for-account.html
Example
use stellar_client::sync::Client; use stellar_client::endpoint::{account, trade, Limit}; let client = Client::horizon_test().unwrap(); // Grab trade and associated account to ensure an account populated with trades let trade_ep = trade::All::default().with_limit(1); let all_trades = client.request(trade_ep).unwrap(); let trade = &all_trades.records()[0]; let account_id = trade.selling_account(); // Now we issue a request for that account's trades let endpoint = account::Trades::new(account_id); let acct_trades = client.request(endpoint).unwrap(); assert!(acct_trades.records().len() > 0);
Methods
impl Trades[src]
impl Tradespub fn new(account_id: &str) -> Self[src]
pub fn new(account_id: &str) -> SelfCreates a new account::Trades endpoint struct. Hand this to the client in order to request trades for a specific account.
use stellar_client::endpoint::account; let trades = account::Trades::new("abc123");