Module stellar_client::endpoint::operation [−][src]
Contains the endpoint for all operations.
Re-exports
pub use super::account::Operations as ForAccount; |
pub use super::ledger::Operations as ForLedger; |
pub use super::transaction::Operations as ForTransaction; |
Structs
| All |
This endpoint represents all operations that have resulted from successful transactions in Stellar. The endpoint will return all operations and accepts query params for a cursor, order, and limit. |
| Details |
The operation details endpoint provides information on a single operation. The operation ID provided in the id argument specifies which operation to load. |
| Effects |
The operation effects endpoint provides a set of effects that are associated with a single operation. The operation ID provided in the id argument specifies which operation to load. |